==> react-native-neurosdk2-1.0.24.tgz: package/android/src/main/java/com/neurosdk2/ScannerHolder.java <==
package com.neurosdk2;

import static com.neurosdk2.Constants.SENSOR_LIST_CHANGED_EVENT_NAME;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.ISensor;
import com.neurosdk2.neuro.Scanner;
import com.neurosdk2.neuro.types.SensorFamily;
import com.neurosdk2.neuro.types.SensorInfo;

import java.util.HashMap;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class ScannerHolder {

  private final HashMap<String, Scanner> _scanners = new HashMap<>();
  private ReactApplicationContext _reactContext;
  public ScannerHolder(ReactApplicationContext context){
    _reactContext = context;
  }

  public void createScanner(ReadableArray filters, Promise promise)
  {
    if (filters == null || filters.size() == 0) {
      promise.reject("createScanner", "filters is null");
      return;
    }

    SensorFamily[] sensorFamilyes = new SensorFamily[filters.size()];
    for(int i = 0; i < filters.size();i++){
      sensorFamilyes[i] = SensorFamily.indexOf(filters.getInt(i));
    }

    String uuid = UUID.randomUUID().toString();
    try{
      _scanners.put(uuid, new Scanner(sensorFamilyes));
      promise.resolve(uuid);
    }
    catch (Exception ex)
    {
      promise.reject("Error while scanner create: ", ex.getLocalizedMessage());
    }
  }

  public void closeScanner(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      scanner.sensorsChanged = null;
      scanner.close();
      _scanners.remove(guid);
    } catch (Exception e) {
      promise.reject("closeScanner", e.getLocalizedMessage());
    }
  }

  public Scanner getScanner(String guid){
    if(_scanners.containsKey(guid)){
      return _scanners.get(guid);
    }
    return null;
  }

  public void startScan(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));

      scanner.sensorsChanged = (sender, list) -> {
        WritableMap result = Arguments.createMap();
        result.putString(GUID_ID, guid);
        WritableArray sensorList = Arguments.createArray();
        for (SensorInfo sensorInfo : list) {
          sensorList.pushMap(sensorInfoToWritableMap(sensorInfo));
        }
        result.putArray(DATA_ID, sensorList);
        sendEvent(_reactContext, SENSOR_LIST_CHANGED_EVENT_NAME.raw(), result);
      };

      scanner.start();
      promise.resolve("success");
    } catch (Exception e) {
      promise.reject("startScan", e.getLocalizedMessage());
    }
  }

  public void stopScan(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      scanner.stop();
      scanner.sensorsChanged = null;
      promise.resolve("success");
    } catch (Exception e) {
      promise.reject("stopScan", e.getLocalizedMessage());
    }
  }

  public void getSensors(String guid, Promise promise) {
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      WritableArray sensorList = Arguments.createArray();
      for (SensorInfo sensorInfo : scanner.getSensors()) {
        sensorList.pushMap(sensorInfoToWritableMap(sensorInfo));
      }
      promise.resolve(sensorList);
    } catch (Exception e) {
      promise.reject("getSensors", e.getLocalizedMessage());
    }
  }

  private WritableMap sensorInfoToWritableMap(SensorInfo sensorInfo) {
    WritableMap sensor = Arguments.createMap();
    sensor.putString("Name", sensorInfo.getName());
    sensor.putString("Address", sensorInfo.getAddress());
    sensor.putString("SerialNumber", sensorInfo.getSerialNumber());
    sensor.putInt("SensModel", sensorInfo.getSensModel());
    sensor.putInt("SensFamily", sensorInfo.getSensFamily().index());
    sensor.putBoolean("PairingRequired", sensorInfo.getPairingRequired());
    sensor.putInt("RSSI", sensorInfo.getRSSI());
    return sensor;
  }
}

==> react-native-neurosdk2-1.0.27.tgz: package/android/src/main/java/com/neurosdk2/ScannerHolder.java <==
package com.neurosdk2;

import static com.neurosdk2.Constants.SENSOR_LIST_CHANGED_EVENT_NAME;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.CxxCallbackImpl;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.ISensor;
import com.neurosdk2.neuro.Scanner;
import com.neurosdk2.neuro.types.SensorFamily;
import com.neurosdk2.neuro.types.SensorInfo;

import java.util.HashMap;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class ScannerHolder {

  private final HashMap<String, Scanner> _scanners = new HashMap<>();
  private ReactApplicationContext _reactContext;
  private CxxCallbackImpl _sensorCallback;
  public ScannerHolder(ReactApplicationContext context){
    _reactContext = context;
  }

  public void createScanner(ReadableArray filters, CxxCallbackImpl sensorCallback, Promise promise)
  {
    if (filters == null || filters.size() == 0) {
      promise.reject("createScanner", "filters is null");
      return;
    }

    SensorFamily[] sensorFamilyes = new SensorFamily[filters.size()];
    for(int i = 0; i < filters.size();i++){
      sensorFamilyes[i] = SensorFamily.indexOf(filters.getInt(i));
    }

    String uuid = UUID.randomUUID().toString();
    try{
      _scanners.put(uuid, new Scanner(sensorFamilyes));
      _sensorCallback = sensorCallback;
      promise.resolve(uuid);
    }
    catch (Exception ex)
    {
      promise.reject("Error while scanner create: ", ex.getLocalizedMessage());
    }
  }

  public void closeScanner(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      scanner.sensorsChanged = null;
      scanner.close();
      _scanners.remove(guid);
    } catch (Exception e) {
      promise.reject("closeScanner", e.getLocalizedMessage());
    }
  }

  public Scanner getScanner(String guid){
    if(_scanners.containsKey(guid)){
      return _scanners.get(guid);
    }
    return null;
  }

  public void startScan(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));

      scanner.sensorsChanged = (sender, list) -> {
        WritableMap result = Arguments.createMap();
        result.putString(GUID_ID, guid);
        WritableArray sensorList = Arguments.createArray();
        for (SensorInfo sensorInfo : list) {
          sensorList.pushMap(sensorInfoToWritableMap(sensorInfo));
        }
        result.putArray(DATA_ID, sensorList);
        if(_sensorCallback == null){
          sendEvent(_reactContext, SENSOR_LIST_CHANGED_EVENT_NAME.raw(), result);
        }
        else {
          _sensorCallback.invoke("onSensorFounded", result);
        }
      };

      scanner.start();
      promise.resolve("success");
    } catch (Exception e) {
      promise.reject("startScan", e.getLocalizedMessage());
    }
  }

  public void stopScan(String guid, Promise promise){
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      scanner.stop();
      scanner.sensorsChanged = null;
      promise.resolve("success");
    } catch (Exception e) {
      promise.reject("stopScan", e.getLocalizedMessage());
    }
  }

  public void getSensors(String guid, Promise promise) {
    try {
      Scanner scanner = Objects.requireNonNull(_scanners.get(guid));
      WritableArray sensorList = Arguments.createArray();
      for (SensorInfo sensorInfo : scanner.getSensors()) {
        sensorList.pushMap(sensorInfoToWritableMap(sensorInfo));
      }
      promise.resolve(sensorList);
    } catch (Exception e) {
      promise.reject("getSensors", e.getLocalizedMessage());
    }
  }

  private WritableMap sensorInfoToWritableMap(SensorInfo sensorInfo) {
    WritableMap sensor = Arguments.createMap();
    sensor.putString("Name", sensorInfo.getName());
    sensor.putString("Address", sensorInfo.getAddress());
    sensor.putString("SerialNumber", sensorInfo.getSerialNumber());
    sensor.putInt("SensModel", sensorInfo.getSensModel());
    sensor.putInt("SensFamily", sensorInfo.getSensFamily().index());
    sensor.putBoolean("PairingRequired", sensorInfo.getPairingRequired());
    sensor.putInt("RSSI", sensorInfo.getRSSI());
    return sensor;
  }
}
